@@ -20,7 +20,7 @@ package
 package PkgConfig;
 
 #First two digits are Perl version, second two are pkg-config version
-our $VERSION = '0.08120_01';
+our $VERSION = '0.08320_01';
 
 require 5.006;
 
@@ -32,6 +32,7 @@ use File::Glob 'bsd_glob';
 use Class::Struct; #in core since 5.004
 use Data::Dumper;
 use File::Basename qw( dirname );
+use Text::ParseWords qw( shellwords );
 
 our $UseDebugging;
 
@@ -376,6 +377,10 @@ struct(
      'print_variable' => '$',
      'print_values' => '$',
      'defined_variables' => '*%',
+     
+     # for creating PkgConfig objects with identical
+     # settings
+     'original' => '$',
     ]
 );
 
@@ -406,6 +411,10 @@ sub _pc_var {
     return $$glob;
 }
 
+sub _quote_cvt($)  {
+    join ' ', map { s/(\s|"|')/\\$1/g; $_ } shellwords(shift)
+}
+
 sub assign_var {
     my ($self,$field,$value) = @_;
     no strict 'refs';
@@ -415,7 +424,7 @@ sub assign_var {
         log_debug("Prefix already defined by user");
         return;
     }
-    my $evalstr = sprintf('$%s = %s',
+    my $evalstr = sprintf('$%s = PkgConfig::_quote_cvt(%s)',
                     $self->_get_pc_varname($field), $value);
     
     log_debug("EVAL", $evalstr);
@@ -455,6 +464,8 @@ sub find {
         ['exclude_cflags', \@DEFAULT_EXCLUDE_CFLAGS]
     );
     
+    my %original = %options;
+    
     foreach (@uspecs) {
         my ($basekey,$default) = @$_;
         my $list = [ @{$options{$basekey} ||= [] } ];
@@ -471,6 +482,7 @@ sub find {
     $VarClassSerial++;
     $options{varclass} = sprintf("PkgConfig::Vars::SERIAL_%d", $VarClassSerial);
     $options{udefclass} = sprintf("PkgConfig::UDefs::SERIAL_%d", $VarClassSerial);
+    $options{original} = \%original;
     
     
     my $udefs = delete $options{VARS} || {};
@@ -608,7 +620,7 @@ sub get_requires {
 sub parse_line {
     my ($self,$line,$evals) = @_;
     no strict 'vars';
-    
+
     $line =~ s/#[^#]+$//g; # strip comments
     return unless $line;
     
@@ -649,14 +661,17 @@ sub parse_line {
     
     $value =~ s/\$\{/\$\{$varclass\::/g;
     
+    # preserve quoted space
+    $value = join ' ', map { s/(["'])/\\$1/g; "'$_'" } shellwords $value
+      if $value =~ /[\\"']/;
+    
     #quoute the value string, unless quouted already
-    $value = "\"$value\"" unless $value =~ /^["']/;
+    $value = "\"$value\"";
     
     #get existent variables from our hash:
     
     
-    $value =~ s/'/"/g; #allow for interpolation
-    
+    #$value =~ s/'/"/g; #allow for interpolation
     $self->assign_var($field, $value);
     
 }
@@ -712,11 +727,18 @@ sub parse_pcfile {
         $self->pkg_description( $self->_pc_var('description') );
         $self->pkg_exists(1);        
     }
-    
+
     unless ($self->no_recurse) {
         foreach (@deps) {
             my ($dep,$cmp_op,$version) = @$_;
-            $self->find_pcfile($dep);
+            $dep = "$dep $cmp_op $version" if defined $cmp_op;
+            my $other = PkgConfig->find($dep, %{ $self->original });
+            if($other->errmsg) {
+                $self->errmsg($other->errmsg);
+                last;
+            }
+            $self->append_cflags(  $other->get_cflags );
+            $self->append_ldflags( $other->get_ldflags );
         }
     }
 }
@@ -831,7 +853,7 @@ sub _split_flags {
     if(@flags == 1) {
         my $str = shift @flags;
         return () if !$str;
-        @flags = split(/\s+/, $str);
+        @flags = map { s/\\(\s)/$1/g; $_ } split(/(?<!\\)\s+/, $str);
     }
     @flags = grep $_, @flags;
     return @flags;
@@ -1522,6 +1544,8 @@ Other contributors include:
 
 =over 4
 
+=item Vladimir Timofeev (vovkasm)
+
 =item kmx
 
 =item Sanel Zukan
